@@ -58,6 +58,7 @@ detect_arch() {
   case "${arch}" in
     x86_64) arch="x86_64" ;;
     aarch64|arm64) arch="arm64" ;;
+    armv6l|armv7l|armv8l) arch="arm" ;;
     *)
       error "Unsupported architecture: ${arch}"
       exit 1
@@ -137,7 +138,7 @@ download_and_install() {
       exit 1
     fi
   else
-    if ! tar -xzvf "${filename}" -C "${extract_dir}"; then
+    if ! tar -xzf "${filename}" -C "${extract_dir}"; then
       error "Failed to extract ${filename}"
       rm -rf "${filename}" "${extract_dir}"
       exit 1
